summaryrefslogtreecommitdiff
path: root/src/landscape.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/landscape.h')
-rw-r--r--src/landscape.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/landscape.h b/src/landscape.h
index 43d9e5f2e..1209c5c1a 100644
--- a/src/landscape.h
+++ b/src/landscape.h
@@ -36,7 +36,7 @@ byte LowestSnowLine();
void ClearSnowLine();
int GetSlopeZInCorner(Slope tileh, Corner corner);
-Slope GetFoundationSlope(TileIndex tile, int *z = NULL);
+Slope GetFoundationSlope(TileIndex tile, int *z = nullptr);
uint GetPartialPixelZ(int x, int y, Slope corners);
int GetSlopePixelZ(int x, int y);
@@ -62,12 +62,12 @@ static inline int GetSlopePixelZInCorner(Slope tileh, Corner corner)
* If a tile does not have a foundation, the function returns the same as GetTilePixelSlope.
*
* @param tile The tile of interest.
* @param z returns the z of the foundation slope. (Can be NULL, if not needed)
* @return The slope on top of the foundation.
*/
static inline Slope GetFoundationPixelSlope(TileIndex tile, int *z)
{
- assert(z != NULL);
+ assert(z != nullptr);
Slope s = GetFoundationSlope(tile, z);
*z *= TILE_HEIGHT;
return s;
@@ -117,7 +117,7 @@ static inline Point InverseRemapCoords(int x, int y)
return pt;
}
-Point InverseRemapCoords2(int x, int y, bool clamp_to_map = false, bool *clamped = NULL);
+Point InverseRemapCoords2(int x, int y, bool clamp_to_map = false, bool *clamped = nullptr);
uint ApplyFoundationToSlope(Foundation f, Slope *s);
/**
@@ -62,12 +62,12 @@ static inline int GetSlopePixelZInCorner(Slope tileh, Corner corner)
*
* @param tile The tile of interest.
- * @param z returns the z of the foundation slope. (Can be NULL, if not needed)
+ * @param z returns the z of the foundation slope. (Can be nullptr, if not needed)
* @return The slope on top of the foundation.
*/